@@ -1,6 +1,7 @@
 from django.contrib.postgres.search import SearchVector
 from django.db.models import Prefetch, Q
 from django_filters import rest_framework as filters
+from rest_framework.exceptions import ValidationError
 
 from ob_dj_store.core.stores.models import (
     Category,
@@ -16,26 +17,38 @@ class StoreFilter(filters.FilterSet):
     """Store filters"""
 
     location = filters.CharFilter(method="by_location")
-    shipping_methods = filters.CharFilter(method="by_shipping_methods")
+    shipping_methods_names = filters.CharFilter(method="by_shipping_methods_names")
     search = filters.CharFilter(method="search_filter")
+    shipping_methods = filters.Filter(method="by_shipping_methods")
 
     class Meta:
         model = Store
         fields = [
             "delivery_charges",
             "min_free_delivery_amount",
+            "shipping_methods",
         ]
 
     def by_location(self, queryset, name, value):
         return queryset.filter(poly__contains=value)
 
-    def by_shipping_methods(self, queryset, name, value):
+    def by_shipping_methods_names(self, queryset, name, value):
         return queryset.filter(
             shipping_methods__name__in=[
                 value,
             ]
         )
 
+    def by_shipping_methods(self, queryset, name, value):
+        """
+        filter stores's shipping methods by ids example: "1,2"
+        """
+        try:
+            ids = [int(v) for v in value.split(",")]
+            return queryset.filter(shipping_methods__in=ids)
+        except ValueError:
+            raise ValidationError("Invalide Value")
+
     def search_filter(self, queryset, name, value):
         return queryset.annotate(
             search=SearchVector("name", "address__address_line")
