@@ -1,15 +1,16 @@
 import contextlib
 import typing
-from datetime import date, time
+from datetime import date, time, timedelta
 
 from django.conf import settings
 from django.contrib.gis.geos import Point
 from django.core.exceptions import ObjectDoesNotExist
+from django.shortcuts import get_object_or_404
 from django.utils.timezone import now
 from django.utils.translation import gettext_lazy as _
 from rest_framework import serializers
 
-from config import settings as tby_settings
+from config import settings as store_settings
 from ob_dj_store.core.stores.models import (
     Attribute,
     AttributeChoice,
@@ -17,6 +18,7 @@ from ob_dj_store.core.stores.models import (
     CartItem,
     Category,
     Favorite,
+    FavoriteExtra,
     Feedback,
     FeedbackAttribute,
     FeedbackConfig,
@@ -138,6 +140,7 @@ class OrderItemSerializer(InventoryValidationMixin, serializers.ModelSerializer)
 class OrderSerializer(serializers.ModelSerializer):
     items = OrderItemSerializer(many=True, read_only=True)
     history = OrderHistorySerializer(many=True, read_only=True)
+    estimated_timeline = serializers.SerializerMethodField()
 
     class Meta:
         model = Order
@@ -153,6 +156,7 @@ class OrderSerializer(serializers.ModelSerializer):
             "items",
             "total_amount",
             "preparation_time",
+            "estimated_timeline",
             "history",
             "pickup_time",
             "extra_infos",
@@ -165,6 +169,29 @@ class OrderSerializer(serializers.ModelSerializer):
             "type_of_order": {"read_only": True, "required": False},
         }
 
+    def get_estimated_timeline(self, obj):
+        timeline = {
+            "pending": obj.created_at,
+            "received": None,
+            "order_ready": None,
+            "delivering": None,
+            "ready": None,
+        }
+        payment = obj.payments.all().first()
+        if not payment:
+            return timeline
+        if payment.payment_post_at:
+            timeline["received"] = payment.payment_post_at
+            timeline["order_ready"] = payment.payment_post_at + timedelta(
+                minutes=obj.preparation_time
+            )
+            if not obj.is_scheduled_for_pickup and obj.shipping_method:
+                timeline["delivering"] = timeline["order_ready"] + timedelta(
+                    minutes=store_settings.ESTIMATED_DELIVERING_TIME
+                )
+            timeline["ready"] = timeline["delivering"] or timeline["order_ready"]
+        return timeline
+
     def to_representation(self, instance):
         data = super().to_representation(instance)
         data["store_name"] = instance.store.name
@@ -219,20 +246,20 @@ class OrderSerializer(serializers.ModelSerializer):
             # validate that the pickup_time is between store's opening hours and closing hours
             if (
                 attrs["store"]
-                .opening_hours.filter(weekday=attrs["pickup_time"].weekday())
+                .opening_hours.filter(weekday=attrs["pickup_time"].weekday() + 1)
                 .exists()
             ) and (
                 attrs["pickup_time"].hour
                 > (
                     attrs["store"]
-                    .opening_hours.filter(weekday=attrs["pickup_time"].weekday())
+                    .opening_hours.filter(weekday=attrs["pickup_time"].weekday() + 1)
                     .first()
                     .to_hour.hour
                 )
                 or attrs["pickup_time"].hour
                 < (
                     attrs["store"]
-                    .opening_hours.filter(weekday=attrs["pickup_time"].weekday())
+                    .opening_hours.filter(weekday=attrs["pickup_time"].weekday() + 1)
                     .first()
                     .from_hour.hour
                 )
@@ -240,10 +267,9 @@ class OrderSerializer(serializers.ModelSerializer):
                 raise serializers.ValidationError(
                     _("Pickup time must be between store's opening hours")
                 )
-
-        if "payment_method" in attrs:
-            payment_method = attrs["payment_method"]
-            if payment_method.payment_provider == tby_settings.WALLET:
+        payment_method = attrs.get("payment_method")
+        if payment_method:
+            if payment_method.payment_provider == store_settings.WALLET:
                 try:
                     wallet = user.wallets.get(country=attrs["store"].address.country)
                 except ObjectDoesNotExist:
@@ -751,7 +777,7 @@ class StoreSerializer(serializers.ModelSerializer):
         data = super().to_representation(instance)
         view = self.context.get("view")
         if view:
-            if view.action == "list":
+            if view.action != "retrieve":
                 return data
         data["inventories"] = InventorySerializer(
             instance.inventories.all(), many=True
@@ -787,3 +813,103 @@ class TaxSerializer(serializers.ModelSerializer):
             "name",
             "value",
         )
+
+
+class StoreListSerializer(serializers.ModelSerializer):
+    class Meta:
+        model = Store
+        fields = "__all__"
+
+
+class GenericSerializer(serializers.Serializer):
+    def to_representation(self, value):
+        context = self.context
+        serializer_class = self.get_serializer_for_instance(value)
+        return serializer_class(context=context).to_representation(value)
+
+    def get_serializer_for_instance(self, instance):
+        serializer_name = type(instance).__name__ + "Serializer"
+        try:
+            return eval(serializer_name)
+        except NameError:
+            raise NameError(_(f"name '{serializer_name}' is not defined"))
+
+
+class FavoriteExtraSerializer(serializers.ModelSerializer):
+    content_object = GenericSerializer(read_only=True)
+    object_id = serializers.IntegerField(min_value=1, write_only=True)
+    object_type = serializers.ChoiceField(
+        write_only=True, choices=store_settings.EXTRA_FAVORITE_TYPES
+    )
+
+    class Meta:
+        model = FavoriteExtra
+        fields = (
+            "id",
+            "content_object",
+            "object_id",
+            "object_type",
+        )
+
+
+class FavoriteSerializer(serializers.ModelSerializer):
+    content_object = GenericSerializer(read_only=True)
+    extras = FavoriteExtraSerializer(many=True)
+    object_id = serializers.IntegerField(min_value=1, write_only=True)
+    object_type = serializers.ChoiceField(
+        write_only=True, choices=store_settings.FAVORITE_TYPES
+    )
+
+    class Meta:
+        model = Favorite
+        fields = (
+            "id",
+            "content_object",
+            "extras",
+            "object_id",
+            "object_type",
+        )
+
+    def validate(self, attrs):
+        validated_data = super().validate(attrs)
+        object_type = validated_data["object_type"]
+        if object_type not in store_settings.FAVORITE_TYPES:
+            raise serializers.ValidationError(
+                _(f"Cannot resolve keyword '{object_type}' into an object type")
+            )
+        object_instance = get_object_or_404(
+            eval(object_type), pk=validated_data["object_id"]
+        )
+        extras_data = {}
+        extras = []
+        for extra in validated_data["extras"]:
+            extra_object_type = extra["object_type"]
+            if extra_object_type not in store_settings.EXTRA_FAVORITE_TYPES:
+                raise serializers.ValidationError(
+                    _(
+                        f"Cannot resolve keyword '{extra_object_type}' into an object type"
+                    )
+                )
+            extras_data.setdefault(extra_object_type, [])
+            extras_data[extra_object_type].append(extra["object_id"])
+        try:
+            for key in extras_data.keys():
+                model_class = eval(key)
+                extras.append(model_class.objects.filter(id__in=extras_data[key]))
+        except ObjectDoesNotExist:
+            raise serializers.ValidationError(_("No matches the given query."))
+        except NameError as e:
+            raise NameError(e)
+        validated_data = {
+            "content_object": object_instance,
+            "extras": extras,
+        }
+        return validated_data
+
+    def create(self, validated_data):
+        favorite = Favorite.add_favorite(
+            validated_data["content_object"],
+            self.context["request"].user,
+            validated_data["extras"],
+        )
+        return favorite
