@@ -6,6 +6,7 @@ from ob_dj_store.apis.stores.views import (
     CartItemView,
     CartView,
     CategoryViewSet,
+    FavoriteViewSet,
     InventoryView,
     OrderView,
     PaymentMethodViewSet,
@@ -38,6 +39,7 @@ router.register(r"category", CategoryViewSet, basename="category")
 router.register(r"transaction", TransactionsViewSet, basename="transaction")
 router.register(r"cart", CartView, basename="cart")
 router.register(r"cart-item", CartItemView, basename="cart-item")
+router.register(r"favorite", FavoriteViewSet, basename="favorite")
 urlpatterns = [
     path(r"", include(router.urls)),
     path(r"", include(stores_router.urls)),
