@@ -7,6 +7,7 @@ from django.utils.decorators import method_decorator
 from django.utils.translation import ugettext_lazy as _
 from django_auto_prefetching import AutoPrefetchViewSetMixin, prefetch
 from django_filters.rest_framework import DjangoFilterBackend
+from drf_yasg import openapi
 from drf_yasg.utils import swagger_auto_schema
 from rest_framework import mixins, permissions, status, viewsets
 from rest_framework.decorators import action
@@ -16,6 +17,7 @@ from rest_framework.response import Response
 from rest_framework_gis.filters import DistanceToPointOrderingFilter
 from rest_framework_nested.viewsets import NestedViewSetMixin
 
+from config import settings as store_settings
 from ob_dj_store.apis.stores.filters import (
     CategoryFilter,
     InventoryFilter,
@@ -29,6 +31,7 @@ from ob_dj_store.apis.stores.rest.serializers.serializers import (
     CartSerializer,
     CategorySerializer,
     CreateOrderResponseSerializer,
+    FavoriteSerializer,
     FeedbackSerializer,
     InventorySerializer,
     OrderSerializer,
@@ -85,6 +88,7 @@ class StoreView(
 
     def get_queryset(self):
         queryset = super().get_queryset()
+        queryset.select_related("opening_hours")
         if self.action == "favorites":
             favorite_store_ids = Favorite.objects.favorites_for_model(
                 Store, self.request.user
@@ -111,10 +115,6 @@ class StoreView(
                 .order_by("-orders__created_at")
                 .distinct()
             )
-        queryset.select_related(
-            "phone_contacts",
-            "opening_hours",
-        )
         return prefetch(queryset, self.serializer_class)
 
     @swagger_auto_schema(
@@ -446,6 +446,7 @@ class ProductView(
             favorite_product_ids = Favorite.objects.favorites_for_model(
                 Product, self.request.user
             ).values_list("object_id", flat=True)
+
             queryset = self.queryset.filter(pk__in=favorite_product_ids)
         return queryset
 
@@ -726,3 +727,69 @@ class TaxViewSet(
     )
     def list(self, request, *args, **kwargs):
         return super().list(request, *args, **kwargs)
+
+
+class FavoriteViewSet(
+    mixins.ListModelMixin,
+    mixins.CreateModelMixin,
+    mixins.DestroyModelMixin,
+    viewsets.GenericViewSet,
+):
+    serializer_class = FavoriteSerializer
+    permission_classes = [
+        permissions.IsAuthenticated,
+    ]
+    queryset = Favorite.objects.all()
+
+    def get_queryset(self):
+        model = self.request.query_params.get("type")
+        if not model and model not in store_settings.FAVORITE_TYPES:
+            raise ValidationError(_("You must"))
+        queryset = Favorite.objects.favorites_for_model(eval(model), self.request.user)
+        return queryset
+
+    @swagger_auto_schema(
+        operation_summary="List Favorites",
+        operation_description="""
+            List Favorites
+        """,
+        manual_parameters=[
+            openapi.Parameter(
+                "type",
+                in_=openapi.IN_QUERY,
+                description="Type of the Favorite item",
+                type=openapi.TYPE_STRING,
+                enum=list(store_settings.FAVORITE_TYPES),
+                required=True,
+            )
+        ],
+        tags=[
+            "Favorite",
+        ],
+    )
+    def list(self, request, *args, **kwargs):
+        return super().list(request, *args, **kwargs)
+
+    @swagger_auto_schema(
+        operation_summary="Add Item To Favorites",
+        operation_description="""
+            Add  Item To Favorites
+        """,
+        tags=[
+            "Favorite",
+        ],
+    )
+    def create(self, request, *args, **kwargs):
+        return super().create(request, *args, **kwargs)
+
+    @swagger_auto_schema(
+        operation_summary="Remove Item From Favorites",
+        operation_description="""
+            Remove  Item From Favorites
+        """,
+        tags=[
+            "Favorite",
+        ],
+    )
+    def destroy(self, request, *args, **kwargs):
+        return super().destroy(request, *args, **kwargs)
