@@ -62,7 +62,7 @@ class StoreAdmin(LeafletGeoAdmin):
     # define the shipping methods field as a ManyToManyField
     # to the shipping method model
     filter_horizontal = ["shipping_methods"]
-    search_fields = ["name", "address"]
+    search_fields = ["name", "address__address_line"]
     list_filter = ("is_active",)
 
     fieldsets = (
@@ -75,7 +75,6 @@ class StoreAdmin(LeafletGeoAdmin):
                     "address",
                     "is_active",
                     "poly",
-                    "currency",
                     "minimum_order_amount",
                     "payment_methods",
                     "pickup_addresses",
