@@ -123,6 +123,12 @@ class FavoriteManager(ActiveMixin, models.Manager):
         return self.get_queryset().get(content_type=content_type, object_id=obj.pk)
 
 
+class FavoriteExtraManager(ActiveMixin, models.Manager):
+    def extras_for_favorite(self, favorite):
+        """Returns extras for a specific favorite"""
+        return self.get_queryset().filter(favorite=favorite)
+
+
 class InventoryOperationsManager(ActiveMixin, models.Manager):
 
     # override create method to set the inventory_quantity
