@@ -1,14 +1,16 @@
-from django.core.exceptions import ObjectDoesNotExist
+from django.core.exceptions import ObjectDoesNotExist, ValidationError
 from django.core.validators import RegexValidator
 from django.db import models
 from django.utils.translation import gettext_lazy as _
+from imagekit.models import ImageSpecField
+from imagekit.processors import ResizeToFill
 
 from ob_dj_store.core.stores.managers import (
     CategoryManager,
     ProductManager,
     ProductVariantManager,
 )
-from ob_dj_store.utils.helpers import product_media_upload_to
+from ob_dj_store.utils.helpers import category_media_upload_to, product_media_upload_to
 from ob_dj_store.utils.model import DjangoModelCleanMixin
 
 
@@ -28,6 +30,16 @@ class Category(DjangoModelCleanMixin, models.Model):
         blank=True,
         related_name="subcategories",
     )
+    image = models.ImageField(upload_to=category_media_upload_to, null=True, blank=True)
+    image_thumbnail = ImageSpecField(
+        source="image",
+        processors=[ResizeToFill(200, 200)],
+        format="JPEG",
+        options={"quality": 60},
+    )
+    order_value = models.PositiveSmallIntegerField(
+        verbose_name=_("ordering"), default=1
+    )
     # Audit fields
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(auto_now=True)
@@ -36,6 +48,7 @@ class Category(DjangoModelCleanMixin, models.Model):
 
     class Meta:
         verbose_name_plural = _("Categories")
+        ordering = ("order_value",)
 
     def __str__(self):
         return f"{self.name}"
@@ -129,6 +142,12 @@ class Product(DjangoModelCleanMixin, models.Model):
     def __str__(self):
         return f"Product {self.name} (PK={self.pk})"
 
+    def save(self, *args, **kwargs):
+        if self.category:
+            if not self.category.parent:
+                raise ValidationError(_("Category Doesn't have a parent"))
+        return super(Product, self).save(*args, **kwargs)
+
 
 # TODO: must remove, redundunt
 class Attribute(DjangoModelCleanMixin, models.Model):
@@ -157,7 +176,11 @@ class AttributeChoice(DjangoModelCleanMixin, models.Model):
 
     name = models.CharField(max_length=200, help_text=_("Name"))
     price = models.DecimalField(
-        max_digits=10, decimal_places=2, default=0, help_text=_("Price")
+        max_digits=10, decimal_places=3, default=0, help_text=_("Price")
+    )
+    description = models.TextField(null=True, blank=True)
+    order_value = models.PositiveSmallIntegerField(
+        verbose_name=_("ordering"), default=1
     )
     # Audit fields
     created_at = models.DateTimeField(auto_now_add=True)
@@ -166,6 +189,7 @@ class AttributeChoice(DjangoModelCleanMixin, models.Model):
     class Meta:
         verbose_name = _("Attribute Choice")
         verbose_name_plural = _("Attribute Choices")
+        ordering = ["price", "order_value", "created_at"]
 
     def __str__(self):
         return f"{self.name}: Attribute Choice  (PK={self.pk})"
@@ -176,15 +200,25 @@ class ProductAttribute(DjangoModelCleanMixin, models.Model):
     ProductAttribute represent a characteristic -attribute- with is choices -attribute_choices-
     """
 
+    class Type(models.TextChoices):
+        ONE_CHOICE = "ONE_CHOICE", _("one choice")
+        MULTIPLE_CHOICES = "MULTIPLE_CHOICES", _("multiple choices")
+
     name = models.CharField(max_length=200, help_text=_("Name"))
-    # TODO: redundunt field
-    # attribute = models.ForeignKey(
-    #     Attribute, on_delete=models.CASCADE, related_name="product_attributes"
-    # )
+    description = models.TextField(null=True, blank=True)
+
     attribute_choices = models.ManyToManyField(
         AttributeChoice, related_name="product_attributes", blank=True
     )
-
+    type = models.CharField(
+        max_length=32,
+        default=Type.ONE_CHOICE,
+        choices=Type.choices,
+    )
+    order_value = models.PositiveSmallIntegerField(
+        verbose_name=_("ordering"), default=1
+    )
+    is_mandatory = models.BooleanField(default=False)
     # Audit fields
     created_at = models.DateTimeField(auto_now_add=True)
     updated_at = models.DateTimeField(auto_now=True)
@@ -192,6 +226,7 @@ class ProductAttribute(DjangoModelCleanMixin, models.Model):
     class Meta:
         verbose_name = _("Product Attribute")
         verbose_name_plural = _("Product Attributes")
+        ordering = ["order_value", "created_at"]
 
     def __str__(self):
         return f"Product Attribute {self.name} (PK={self.pk})"
@@ -210,7 +245,6 @@ class ProductVariant(DjangoModelCleanMixin, models.Model):
     product_attributes = models.ManyToManyField(
         ProductAttribute, related_name="product_variants", blank=True
     )
-    has_inventory = models.BooleanField(default=True)
     sku = models.CharField(max_length=100, null=True, blank=True)
     # Audit fields
     created_at = models.DateTimeField(auto_now_add=True)
@@ -225,6 +259,10 @@ class ProductVariant(DjangoModelCleanMixin, models.Model):
     def __str__(self):
         return f"Product Variation {self.name} (PK={self.pk})"
 
+    @property
+    def has_inventory(self):
+        return self.inventories.count() > 0
+
 
 class ProductMedia(DjangoModelCleanMixin, models.Model):
     """
@@ -239,6 +277,12 @@ class ProductMedia(DjangoModelCleanMixin, models.Model):
     )
     is_primary = models.BooleanField(default=False)
     image = models.ImageField(upload_to=product_media_upload_to)
+    image_thumbnail = ImageSpecField(
+        source="image",
+        processors=[ResizeToFill(200, 200)],
+        format="JPEG",
+        options={"quality": 60},
+    )
     order_value = models.PositiveSmallIntegerField(
         verbose_name=_("ordering"), default=1
     )
