@@ -11,6 +11,7 @@ from ob_dj_store.core.stores.managers import (
     ShippingMethodManager,
     StoreManager,
 )
+from ob_dj_store.core.stores.utils import get_currency_by_country
 from ob_dj_store.utils.model import DjangoModelCleanMixin
 
 
@@ -98,7 +99,6 @@ class Store(DjangoModelCleanMixin, models.Model):
     location = models.PointField(null=True, blank=True)
     is_active = models.BooleanField(default=True)
     poly = models.PolygonField(null=True, blank=True)
-    currency = models.CharField(max_length=20)
     shipping_methods = models.ManyToManyField(
         ShippingMethod,
         related_name="shipping_methods",
@@ -147,6 +147,12 @@ class Store(DjangoModelCleanMixin, models.Model):
     def __str__(self) -> typing.Text:
         return f"Store {self.name} (PK={self.pk})"
 
+    @property
+    def currency(self):
+        if self.address:
+            return get_currency_by_country(self.address.country.name)
+        return None
+
 
 class OpeningHours(DjangoModelCleanMixin, models.Model):
     """
