@@ -15,7 +15,8 @@ def create_customer_cart_and_wallet_handler(sender, instance, created, **kwargs)
         return
     cart = Cart(customer=instance)
     cart.save()
-    Wallet.objects.create(user=instance)
+    country = getattr(instance, "country", None)
+    Wallet.objects.create(user=instance, country=country)
 
 
 # add receiver to ProductVariant to create inventory
