@@ -1,5 +1,9 @@
 import math
 
+import pycountry
+from django.core.exceptions import ValidationError
+from django.utils.translation import gettext_lazy as _
+
 
 def get_data_dict(instance):
     """
@@ -47,3 +51,17 @@ def distance(origin, destination):
     d = radius * c
 
     return d
+
+
+def get_currency_by_country(country):
+    country = pycountry.countries.get(name=country)
+    if not country:
+        raise ValidationError(_("Invalid Country!"))
+    return pycountry.currencies.get(numeric=country.numeric).alpha_3
+
+
+def get_country_by_currency(currency):
+    currency = pycountry.currencies.get(alpha_3=currency)
+    if not currency:
+        raise ValidationError(_("Invalid Currency!"))
+    return pycountry.countries.get(numeric=currency.numeric).alpha_2
